@@ -88,9 +88,6 @@ pub mod bigtable;
 #[cfg(any(feature = "google-bytestream",))]
 pub mod bytestream;
 
-#[cfg(any(feature = "google-chat-dynamite-integration-logging-v1",))]
-pub mod chat;
-
 #[cfg(any(
     feature = "google-chromeos-moblab-v1beta1",
     feature = "google-chromeos-uidetection-v1",
@@ -187,6 +184,7 @@ pub mod chromeos;
     feature = "google-cloud-gaming-v1",
     feature = "google-cloud-gaming-v1beta",
     feature = "google-cloud-gkebackup-logging-v1",
+    feature = "google-cloud-gkebackup-v1",
     feature = "google-cloud-gkeconnect-gateway-v1",
     feature = "google-cloud-gkeconnect-gateway-v1alpha1",
     feature = "google-cloud-gkeconnect-gateway-v1beta1",
