@@ -59,7 +59,6 @@ pub mod ccc;
     feature = "google-bigtable-admin-v2",
     feature = "google-bigtable-v2",
     feature = "google-bytestream",
-    feature = "google-chat-dynamite-integration-logging-v1",
     feature = "google-chromeos-moblab-v1beta1",
     feature = "google-chromeos-uidetection-v1",
     feature = "google-cloud",
@@ -151,6 +150,7 @@ pub mod ccc;
     feature = "google-cloud-gaming-v1",
     feature = "google-cloud-gaming-v1beta",
     feature = "google-cloud-gkebackup-logging-v1",
+    feature = "google-cloud-gkebackup-v1",
     feature = "google-cloud-gkeconnect-gateway-v1",
     feature = "google-cloud-gkeconnect-gateway-v1alpha1",
     feature = "google-cloud-gkeconnect-gateway-v1beta1",
